/*
 * SCIM Bridge
 *
 * Copyright (c) 2006 Ryo Dairiki <ryo-dairiki@users.sourceforge.net>
 *
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.*
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU Lesser General Public License for more details.*
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

/**
 * @file
 * @author Ryo Dairiki <ryo-dairiki@users.sourceforge.net>
 * @brief This is the header for gtk imcontext of scim-bridge.
 */


#ifndef SCIMBRIDGECLIENTIMCONTEXTGTK_H_
#define SCIMBRIDGECLIENTIMCONTEXTGTK_H_

#include <gtk/gtk.h>
#include <gtk/gtkimcontext.h>

#include <gdk/gdk.h>

#include "scim-bridge.h"
#include "scim-bridge-client-imcontext.h"

#define GTK_TYPE_SCIM_CLIENT_IMCONTEXT (scim_bridge_client_imcontext_get_type ())
#define SCIM_BRIDGE_CLIENT_IMCONTEXT(obj) (GTK_CHECK_CAST ((obj), GTK_TYPE_SCIM_CLIENT_IMCONTEXT, ScimBridgeClientIMContext))
#define SCIM_BRIDGE_CLIENT_IMCONTEXT_CLASS(klass) (GTK_CHECK_CLASS_CAST ((klass), GTK_TYPE_SCIM_CLIENT_IMCONTEXT, ScimBridgeClientIMContextClass))
#define IS_SCIM_BRIDGE_CLIENT_IMCONTEXT(class) (GTK_CHECK_TYPE ((obj), GTK_TYPE_SCIM_CLIENT_IMCONTEXT))
#define IS_SCIM_BRIDGE_CLIENT_IMCONTEXT_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), GTK_TYPE_SCIM_CLIENT_IMCONTEXT))
#define SCIM_BRIDGE_CLIENT_IMCONTEXT_GET_CLASS(obj) (GTK_CHECK_GET_CLASS ((obj), GTK_TYPE_SCIM_CLIENT_IMCONTEXT, ScimBridgeClientIMContextClass))

struct _ScimBridgeClientIMContextClass
{
    GtkIMContextClass parent_class;
};

/**
 * IMContext class for gtk client.
 */
typedef struct _ScimBridgeClientIMContextClass ScimBridgeClientIMContextClass;

/**
 * Initialize IMContext class itself.
 */
void scim_bridge_client_imcontext_static_initialize ();

/**
 * Finalize IMContext class itself.
 */
void scim_bridge_client_imcontext_static_finalize ();

/**
 * The connection with the agent is opened.
 */
void scim_bridge_client_imcontext_connection_opened ();

/**
 * The connection with the agent is closed.
 */
void scim_bridge_client_imcontext_connection_closed ();

/**
 * Allocate an IMContext.
 *
 * @return new IMContext.
 */
GtkIMContext *scim_bridge_client_imcontext_new ();

/**
 * Get the type value of IMContexts.
 *
 * @return The type value of IMContexts.
 */
GType scim_bridge_client_imcontext_get_type ();

/**
 * Register the type value for IMContexts.
 *
 * @param type_module The type module.
 */
void scim_bridge_client_imcontext_register_type (GTypeModule *type_module);

#endif                                            /*SCIMBRIDGECLIENTIMCONTEXTGTK_H_*/
